export function getServersAndRepositories (v) {
  const CONFIG = {
    servers: [
      {
        name: "dev.funkwhale.audio",
        protocol: "https",
        apiPath: "/api/v4/",
        type: 'gitlab',
        params: {
          per_page: 15,
          'not[labels]': 'Status: Draft',
        },
      }
    ],
    serversByName: {},
    repositories: [
      {
        server: "dev.funkwhale.audio",
        namespace: "funkwhale",
        groupId: 39,
        label: 'Funkwhale',
        categories: [
          {
            label: v.$pgettext("Task summary", 'Complete the task'),
            taskSlug: 'improve-documentation',
            filters: {
              milestone: 'Any',
              labels: 'Area: Documentation',
              'not[labels]': 'Type: New feature',
            }
          },
          {
            label: 'Complete the task',
            taskSlug: 'talk-about-funkwhale',
            filters: {
              labels: 'Area: Content',
            }
          },
          {
            label: 'Complete the task',
            taskSlug: 'small-issue',
            filters: {
              milestone: 'Any',
              labels: 'Difficulty: Easy-pick',
            }
          },
          {
            label: 'Review contribution',
            taskSlug: 'review-contribution',
            entityType: 'merge_requests',
            filters: {
              wip: 'no',
              labels: 'Status: Review wanted',
            }
          },
          {
            label: 'Review contribution',
            taskSlug: 'review-contribution',
            entityType: 'merge_requests',
            filters: {
              wip: 'no',
              labels: 'Status: input wanted',
            }
          },
          {
            label: 'Review contribution',
            taskSlug: 'review-contribution',
            filters: {
              labels: 'Status: Review wanted',
            }
          },
          {
            label: 'Support',
            summary: 'Help someone',
            taskSlug: 'support-community-members',
            filters: {
              labels: 'Type: Support'
            }
          },
          {
            label: 'Triage task',
            taskSlug: 'triage-tasks',
            filters: {
              labels: 'Status: need triage'
            }
          },
          {
            label: 'Triage task',
            taskSlug: 'triage-tasks',
            filters: {
              labels: 'None'
            }
          },
        ]
      },
    ],
    repositoriesById: {}
  }

  CONFIG.servers.forEach((s) => {
    s.baseApiUrl = `${s.protocol}://${s.name}${s.apiPath}`
    CONFIG.serversByName[s.name] = s
  })

  CONFIG.repositories.forEach((r) => {
    r.serverObj = CONFIG.serversByName[r.server]
    r.id = `${r.serverObj.name}/${r.namespace}/${r.id}`
  })
  return CONFIG
}

export function getTasks (v) {
  return [
    {
      name: v.$pgettext("Task name", 'Become a backer'),
      duration: 5,
      icon: "eur",
      slug: 'become-backer',
      summary: v.$pgettext("Task summary", 'Support Funkwhale financially, on a one-time or recurring basis.'),
      skills: [],
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Decide how much you want to give'),
          content: [v.$pgettext("Guide step content", "Both one-time and recurring donations are accepted with joy, starting at 1€. Smaller but recurring donations provide more smiles than big one time payments."),],
          media: [
            {
              type: 'image',
              url: '/assets/guides/backer/tier-one-time.png',
              caption: v.$pgettext("Task image caption", 'One-time tier on Open Collective')
            },
            {
              type: 'image',
              url: '/assets/guides/backer/tier-backer.png',
              caption: v.$pgettext("Task image caption", 'Backer tier on Open Collective')
            },
            {
              type: 'image',
              url: '/assets/guides/backer/tier-sponsor.png',
              caption: v.$pgettext("Task image caption", 'Sponsor tier on Open Collective')
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Create an Open Collective account'),
          optional: true,
          content: [v.$pgettext("Guide step content", "You don't need an account to send donations, but this may be useful if you want to have a profile or manage your payment options."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Open Collective'),
              url: 'https://opencollective.com/signin'
            }
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Visit the Open Collective page'),
          content: [v.$pgettext("Guide step content", "Pick the one you prefer from a list of backing options."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Funkwhale page on Open Collective'),
              url: 'https://opencollective.com/funkwhale'
            }
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Proceed to payment'),
          content: [v.$pgettext("Guide step content", "Enter your payment details and send the payment."),],
        }
      ]
    },
    {
      name: v.$pgettext("Task name", "Talk about Funkwhale"),
      duration: 5,
      icon: "share",
      hasList: true,
      summary: v.$pgettext("Task summary", "Increase the awareness of Funkwhale within audible range of your megaphone."),
      slug: 'talk-about-funkwhale',
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Choose your audience'),
          content: [
            v.$pgettext("Guide step content", "Who could be interested by Funkwhale within your circle? Funkwhale may be interesting for musicians, music or podcasts lovers, free/federated software fans…"),
          ],
          recommendations: [
            v.$pgettext("Advice content / recommendations", "Pick someone, or a group of people likely to be excited about Funkwhale."),
            v.$pgettext("Advice content / recommendations", "Address people or communities that run with you."),
          ],
          avoid: [
            v.$pgettext("Advice content / avoid", "Other people, nobody likes other people, it will likely hurt the project. Stranger danger."),
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Choose your medium'),
          content: [
            v.$pgettext("Guide step content", "Choose a medium your audience is comfortable with. Typical media include: SMS, forums, social media, private messaging systems, oral discussion, etc."),
          ],
          recommendations: [
            v.$pgettext("Advice content / recommendations", "Use a medium you are familiar with."),
          ],
        },
        {
          title: v.$pgettext("Guide step title", 'Write your message'),
          content: [
            v.$pgettext("Guide step content", "Write an appropriate message based on your medium and audience. In your own words, explain why you think Funkwhale may interest them."),
            v.$pgettext("Guide step content", "If relevant and possible, include at least a link to https://funkwhale.audio/, to give them the opportunity learn more about the project, at their own pace."),
            v.$pgettext("Guide step content", "Including screenshots or videos may also be helpful to reach different kind of people."),
          ],
          recommendations: [
            v.$pgettext("Advice content / recommendations", "Use your own words"),
            v.$pgettext("Advice content / recommendations", "Include links, screenshots or other media, if relevant"),
            v.$pgettext("Advice content / recommendations", "Ensure your message respect the medium rules, if any"),
          ],
          avoid: [
            v.$pgettext("Advice content / avoid", "Copy-pasting existing content"),
          ]
        },
      ]
    },
    {
      name: v.$pgettext("Task name", "Share your feedback"),
      duration: 5,
      icon: "comment",
      summary: v.$pgettext("Task summary", "How happy are you with the project? Let us know!"),
      slug: "share-feedback",
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Choose your medium'),
          content: [
            v.$pgettext("Guide step content", "You can share your feedback with us on various platforms. You'll find the links below."),
          ],
          links: [
            {
              icon: 'comment',
              text: v.$pgettext("Text for link in guide step", 'Share your feedback on our forum'),
              to: {name: 'guide', params: {slug: 'forum-account', locale: v.$language.current}},
            },
            {
              icon: 'mastodon',
              text: v.$pgettext("Text for link in guide step", 'Share your feedback on Mastodon'),
              url: 'https://mastodon.eliotberriot.com/@funkwhale',
            },
            {
              icon: 'matrix-org',
              text: v.$pgettext("Text for link in guide step", 'Share your feedback on #funkwhale:Matrix.org'),
              url: 'https://riot.im/app/#/room/#funkwhale:matrix.org',
            }
          ],
          avoid: [
            v.$pgettext("Advice content / avoid", "Publishing your feedback on other platforms is not going to go well, it's likely to be missed"),
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Write your message'),
          content: [
            v.$pgettext("Guide step content", "Tell us how you felt using Funkwhale. What did you like or dislike? What would you like to see improved?"),
            v.$pgettext("Guide step content", "Remember, the job of receiving feedback is one we run on humans, just like you. We assume a mix of positive and negative feedback, no personal attacks or rude language."),
          ],
          recommendations: [
            v.$pgettext("Advice content / recommendations", "Be specific: Precise feedback is the most helpful"),
          ],
          avoid: [
            v.$pgettext("Advice content / avoid", "Use of rude, or aggressive language"),
          ]
        },
      ]
    },
    {
      name: v.$pgettext('Task name', "Join the discussion"),
      duration: 15,
      slug: "join-discussion",
      icon: "comment",
      summary: v.$pgettext("Task summary", 'Help the Funkwhale whale go in the right direction.'),
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Create your Forum account'),
          content: [v.$pgettext("Guide step content", 'Project discussions take place at forum.funkwhale.audio, which uses Flarum. Browse without an account, or get one to contribute to the discussions.'),],
          links: [
            {
              icon: 'comment',
              text: v.$pgettext("Text for link in guide step", 'Create your forum account'),
              to: {name: 'guide', params: {slug: 'forum-account', locale: v.$language.current}},
            }
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Read the Code of Conduct'),
          content: [v.$pgettext("Guide step content", 'Our Code of Conduct applies to all the community spaces, including the forum.'),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Read the Code of Conduct'),
              url: 'https://funkwhale.audio/code-of-conduct/',
            }
          ],
        },
        {
          title: v.$pgettext("Guide step title", 'Discuss'),
          content: [v.$pgettext("Guide step content", 'Browse the forum for topics of interest. Lurk, or add your input in discussions and debate. Answer other people\'s question. Introduce yourself in a dedicated post if you want, and get in touch with the rest of the community 😃'),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'New posts from the forum'),
              url: 'https://forum.funkwhale.audio/all',
            }
          ],
        }
      ]
    },
    {
      name: v.$pgettext('Task name', "Translate Funkwhale"),
      duration: 15,
      icon: "language",
      summary: v.$pgettext("Task summary", 'Help translate the project to other languages.'),
      slug: 'translate',
      skills: [
        {
          name: v.$pgettext("Skill name", 'Comprehend English'),
          summary: v.$pgettext("Skill summary", "You need to understand written English to translate Funkwhale to another language.")
        },
        {
          name: v.$pgettext("Skill name", 'Be fluent in another language'),
          summary: v.$pgettext("Skill summary", "Good, you meet the requirements of translating Funkwhale into that language.")
        },
      ],
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Create your Contributor Account'),
          content: [v.$pgettext("Guide step content", 'A Gitlab on dev.funkwhale.audio will also work on translate.funkwhale.audio.'),],
          links: [
            {
              icon: 'gitlab',
              text: v.$pgettext("Text for link in guide step", 'Create your GitLab account'),
              to: {name: 'guide', params: {slug: 'gitlab-account', locale: v.$language.current}},
            }
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Review the translation guidelines'),
          content: [v.$pgettext("Guide step content", "Translator guidelines are available to ensure consistency across languages and components. Take a moment to read this document."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Translation guidelines'),
              url: 'https://docs.funkwhale.audio/translators.html#guidelines'
            }
          ],
        },
        {
          title: v.$pgettext("Guide step title", 'Choose the project you want to translate'),
          content: [v.$pgettext("Guide step content", "Funkwhale is made up of several projects, also known as components in Weblate's terminology. Pick your favourite, or \"Contribute\" to translate this website."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'List of translatable components'),
              url: 'https://translate.funkwhale.audio/projects/funkwhale/'
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/translate/component-list.png',
              caption: v.$pgettext("Task image caption", 'List of available components and translation progress for each')
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Choose the target language'),
          content: [v.$pgettext("Guide step content", "Each component is translated in many languages. Pick a language your are fluent in."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'List of already available languages'),
              url: 'https://translate.funkwhale.audio/projects/funkwhale/front/'
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/translate/language-list.png',
              caption: v.$pgettext("Task image caption", 'List of available languages with progressing translations')
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Log in on Weblate'),
          content: [v.$pgettext("Guide step content", 'Weblate is where translations happen. Log in with your GitLab account using the "Third party login" section on the right to start translating.'),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Log in on Weblate with GitLab'),
              url: 'https://translate.funkwhale.audio/accounts/login/?next=/projects/funkwhale/front/'
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/translate/login-form.png',
              caption: v.$pgettext("Task image caption", "Weblate's login form with GitLab login on the right")
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Configure your languages'),
          content: [v.$pgettext("Guide step content", "Telling Weblate what languages you understand/translate will make it easier afterwards. You can also take a moment to edit your account profile and settings if needed."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Configure your languages'),
              url: 'https://translate.funkwhale.audio/accounts/profile/'
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/translate/profile-languages.png',
              caption: v.$pgettext("Task image caption", "Pick one or more translated and/or secondary languages in the form")
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Click "Translate"'),
          content: [v.$pgettext("Guide step content", 'Click on the "translate" button in the last column of the languages table to start working.'),],
          media: [
            {
              type: 'image',
              url: '/assets/guides/translate/translate-button.png',
              caption: v.$pgettext("Task image caption", "The translate button is located in the last column")
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Submit your first translation'),
          content: [v.$pgettext("Guide step content", "Weblate will now present you with text in need of translation or correction. Confidently submit a translation, or fill-in your proposal and submit the form. If you're not sure at all, comment or move to the next string."),],
          media: [
            {
              type: 'image',
              url: '/assets/guides/translate/translation-form-complete.png',
              caption: v.$pgettext("Task image caption", "A complete overview of the translation form")
            },
            {
              type: 'image',
              url: '/assets/guides/translate/translation-form-translate-area.png',
              caption: v.$pgettext("Task image caption", "The translate area is where most of your work will happen")
            },
            {
              type: 'image',
              url: '/assets/guides/translate/translation-form-action-bar.png',
              caption: v.$pgettext("Task image caption", "The top bar helps you navigate the translations and see your progress")
            },
            {
              type: 'image',
              url: '/assets/guides/translate/translation-form-check.png',
              caption: v.$pgettext("Task image caption", "The \"Checks\" area tells you what you need to do for a given translation")
            },
            {
              type: 'image',
              url: '/assets/guides/translate/translation-form-menu.png',
              caption: v.$pgettext("Task image caption", "Use the submenu to browse similar translations, see other translators comments, suggestions and past activity")
            },
            {
              type: 'image',
              url: '/assets/guides/translate/translation-form-source.png',
              caption: v.$pgettext("Task image caption", 'The "Source information" section can help you find contextual info about a translation, and see the source-code in which the translation is used')
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Stop here… or continue!'),
          content: [v.$pgettext("Guide step content", "You can repeat the previous step until you run out of time. Each new or improved translation makes the project better."),],
        },
      ]
    },
    {
      name: v.$pgettext('Task name', "Report a bug"),
      icon: "bug",
      slug: 'report-a-bug',
      duration: 15,
      summary: v.$pgettext("Task summary", "Report typos, display issues, or other unexpected bebaviour, or fix it yourself."),
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Search for similar bugs'),
          content: [
            v.$pgettext("Guide step content", "A quick search can yield similar bug and avoid opening duplicates. Take a minute or two to search our issue tracker for recent bug reports that could match yours, but don't worry if you open a duplicate: a contributor will handle it :)"),
            v.$pgettext("Guide step content", "If you find a similar bug report, you can comment on this one instead of creating a new one."),
            v.$pgettext("Guide step content", "If you are unsure about submitting a bug report or have other general tech questions, you can also start a thread in the support topic on our forum, or ask us on our Fediverse account."),
          ],
          links: [
            {
              icon: 'gitlab',
              text: v.$pgettext("Text for link in guide step", 'Browse existing bugs'),
              url: 'https://dev.funkwhale.audio/funkwhale/funkwhale/issues?label_name%5B%5D=Type%3A+Bug',
            },
            {
              icon: 'comment',
              text: v.$pgettext("Text for link in guide step", 'Start a thread on our support forum'),
              url: 'https://forum.funkwhale.audio/t/support',
            },
            {
              icon: 'mastodon',
              text: v.$pgettext("Text for link in guide step", 'Get in touch on the Fediverse'),
              url: 'https://mastodon.eliotberriot.com/@funkwhale',
            }
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Create your Contributor Account'),
          content: [v.$pgettext("Guide step content", 'This account is needed to submit your bug report or comments.'),],
          links: [
            {
              icon: 'gitlab',
              text: v.$pgettext("Text for link in guide step", 'Create your GitLab account'),
              to: {name: 'guide', params: {slug: 'gitlab-account', locale: v.$language.current}},
            }
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Write your bug report'),
          content: [
            v.$pgettext("Guide step content", 'Select "Bug" in the issue template dropdown, then fill the title and content for your bug report.'),
            v.$pgettext("Guide step content", 'Try to be as precise and specific as possible: the other contributors that will read your report may not know things that are obvious to you.'),
            v.$pgettext("Guide step content", "We know writing an actionable bug report is hard. Do your best and give as much context as possible, but don't worry: other contributors will reach out to you if they need more details."),
          ],
          recommendations: [
            v.$pgettext("Advice content / recommendations", "Explain what you were trying to do"),
            v.$pgettext("Advice content / recommendations", "Explain what you expected to happen"),
            v.$pgettext("Advice content / recommendations", "Explain what actually happened"),
            v.$pgettext("Advice content / recommendations", "Include logs, error messages, screenshots and information about your system (web browser, operating system…), if applicable"),
            v.$pgettext("Advice content / recommendations", "Include the version number of the Funkwhale server on which the issue happens"),
          ],
          avoid: [
            v.$pgettext("Advice content / avoid", 'Use vague language such as "this is not working"'),
          ],
          links: [
            {
              icon: 'pencil',
              text: v.$pgettext("Text for link in guide step", 'Write your bug report'),
              url: "https://dev.funkwhale.audio/funkwhale/funkwhale/issues/new?issue%5Bassignee_id%5D=&issue%5Bmilestone_id%5D=",
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/report-a-bug/template.png',
              caption: v.$pgettext("Task image caption", 'Choose "bug" in the issue template drowdown')
            },
            {
              type: 'image',
              url: '/assets/guides/report-a-bug/log.png',
              caption: v.$pgettext("Task image caption", 'Put logs between three ` (backticks)')
            },
            {
              type: 'image',
              url: '/assets/guides/report-a-bug/full-example.png',
              caption: v.$pgettext("Task image caption", "A complete exemple of a bug report")
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Review and submit your report'),
          content: [
            v.$pgettext("Guide step content", 'Read your report one last time, then click on the "Submit" button.'),
            v.$pgettext("Guide step content", 'A contributor will have a look at it within the next days!'),
          ],
        }
      ]
    },
    {
      name: v.$pgettext('Task name', "Publish audio content"),
      icon: "music",
      duration: 15,
      summary: v.$pgettext("Task summary", "Upload content with a libre licence, or your own work, on the network."),
    },
    {
      slug: 'improve-documentation',
      name: v.$pgettext('Task name', "Submit feedback and patches for the documentation"),
      icon: "pencil",
      duration: 30,
      hasList: true,
      summary: v.$pgettext("Task summary", "Fix and report issues to improve the quality of the documentation. You can also review work done by others."),
    },
    {
      name: v.$pgettext('Task name', "Request a feature"),
      icon: "question",
      slug: "request-a-feature",
      duration: 30,
      summary: v.$pgettext("Task summary", "Is something missing in Funkwhale? Write a feature request and spark a discussion about it."),
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Search for similar requests'),
          content: [
            v.$pgettext("Guide step content", 'It\'s possible that the feature you want was already requested by someone else. Take a minute or two to look at our roadmap and at the "Feature Request" category on our forum.'),
            v.$pgettext("Guide step content", "If you find a similar request, it will be more productive to join the existing discussion instead of opening a new one. Don't worry if you open a duplicate: a contributor will handle it :)"),
          ],
          links: [
            {
              icon: 'comment',
              text: v.$pgettext("Text for link in guide step", 'Browse existing requests'),
              url: 'https://forum.funkwhale.audio/t/development',
            },
            {
              icon: 'map-o',
              text: v.$pgettext("Text for link in guide step", 'Read our roadmap'),
              url: 'https://pad.funkwhale.audio/roadmap',
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Create a forum account'),
          content: [
            v.$pgettext("Guide step content", "An account is required to join or open new discussions on the forum."),
          ],
          links: [
            {
              icon: 'comment',
              text: v.$pgettext("Text for link in guide step", 'Open a forum account'),
              to: {name: 'guide', params: {slug: 'forum-account', locale: v.$language.current}},
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Write your request'),
          content: [
            v.$pgettext("Guide step content", "Take some time to write your request. Explain what you want to achieve, why it's not possible to do it currently, how it could improve the project."),
            v.$pgettext("Guide step content", "Give as much context as possible so other readers can understand your needs."),
            v.$pgettext("Guide step content", "It's also extremely important to describe the issue you want to solve instead of discribing a solution to this issue, because different or more efficient solutions you don't know could exist."),
          ],
          recommendations: [
            v.$pgettext("Advice content / recommendations", "Explain what you need"),
            v.$pgettext("Advice content / recommendations", "Share links and references to projects that have a similar feature"),
          ],
          avoid: [
            v.$pgettext("Advice content / avoid", 'Request a specific solution'),
          ],
          links: [
            {
              icon: 'pencil',
              text: v.$pgettext("Text for link in guide step", 'Write your request'),
              url: "https://forum.funkwhale.audio/t/development",
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/request-a-feature/new-thread.png',
              caption: v.$pgettext("Task image caption", 'Start a thread by clicking the "New Thread" button')
            },
            {
              type: 'image',
              url: '/assets/guides/request-a-feature/full-example.png',
              caption: v.$pgettext("Task image caption", "A simple feature request")
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Review and submit your request'),
          content: [
            v.$pgettext("Guide step content", 'Read your request one last time, then click on the "Submit" button.'),
            v.$pgettext("Guide step content", 'Other contributors will soon join the discussion and give you feedback.'),
          ],
        }
      ]
    },
    {
      slug: 'support-community-members',
      hasList: true,
      name: v.$pgettext('Task name', "Support other community members"),
      icon: "wrench",
      duration: 30,
      summary: v.$pgettext("Task summary", "Help other community members troubleshot and solve their issues while installing or using Funkwhale."),
    },
    {
      name: v.$pgettext('Task name', "Review submitted patches"),
      slug: 'review-contribution',
      hasList: true,
      icon: "eye",
      duration: 30,
      summary: v.$pgettext("Task summary", "Review work submitted by other contributors to increase software quality."),
    },
    {
      name: v.$pgettext('Task name', "Solve a small issue"),
      slug: 'small-issue',
      hasList: true,
      icon: "file-code-o",
      duration: 60,
      summary: v.$pgettext("Task summary", "Improve the project by fixing a reported bug or implementing a requested enhancement."),
    },
    {
      name: v.$pgettext('Task name', "Triage tasks"),
      slug: 'triage-tasks',
      hasList: true,
      icon: "tags",
      duration: 15,
      summary: v.$pgettext("Task summary", "Triage newly created tasks and topics so that other people can find them."),
    },
    {
      name: v.$pgettext('Task name', "Open a Funkwhale pod"),
      icon: "server",
      duration: 120,
      instructionsUrl: 'https://docs.funkwhale.audio/installation/index.html',
      summary: v.$pgettext("Task summary", "Hosting your own Funkwhale and opening it to other people makes the network stronger and more attractive."),
    },
    {
      name: v.$pgettext('Task name', "Integrate Funkwhale with other projects"),
      icon: "file-code-o",
      duration: 9999,
      summary: v.$pgettext("Task summary", "Write an app, an alternative client for Funkwhale, or integrate Funkwhale in third-party projects."),
    },
    // hidden tasks (on home) that can be included in other guides
    {
      name: v.$pgettext('Task name', "Create a GitLab account"),
      icon: "gitlab",
      duration: 5,
      unlisted: true,
      slug: 'gitlab-account',
      summary: v.$pgettext("Task summary", 'Create your GitLab account on dev.funkwhale.audio to start working on various projects.'),
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Visit dev.funkwhale.audio'),
          content: [v.$pgettext("Guide step content", 'The Funkwhale GitLab instance is hosted at dev.funkwhale.audio. You have to sign-up here, using your e-mail account or by way of a third-party token provider.'),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Sign up on dev.funkwhale.audio'),
              url: 'https://dev.funkwhale.audio/users/sign_in',
            },
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/gitlab-account/signup-form.png',
              caption: v.$pgettext("Task image caption", 'Sign-up form')
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Verify your e-mail address'),
          content: [v.$pgettext("Guide step content", "Shortly after signup, you should receive a confirmation e-mail containing an activation link. Click it to activate your account. Request another one if you did not receive the e-mail within a few minutes."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Request another activation e-mail'),
              url: 'https://dev.funkwhale.audio/users/almost_there',
            }
          ],
        },
        {
          title: v.$pgettext("Guide step title", 'Log in'),
          content: [v.$pgettext("Guide step content", "Log in using your new account to ensure everything works properly."),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Login form'),
              url: 'https://dev.funkwhale.audio/users/sign_in',
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/gitlab-account/login-form.png',
              caption: v.$pgettext("Task image caption", 'Login form')
            },
          ],
        },
        {
          title: v.$pgettext("Guide step title", 'Customize your profile'),
          optional: true,
          content: [v.$pgettext("Guide step content", "Take a few minutes to customize your profile and upload your avatar. This will help other community members know who you are :)"),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Profile form'),
              url: 'https://dev.funkwhale.audio/profile',
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/gitlab-account/user-dropdown.png',
              caption: v.$pgettext("Task image caption", 'Settings dropdown to access the profile form')
            },
            {
              type: 'image',
              url: '/assets/guides/gitlab-account/profile-form.png',
              caption: v.$pgettext("Task image caption", 'The profile form')
            },
          ],
        }
      ]
    },
    {
      name: v.$pgettext('Task name', "Create a forum account"),
      icon: "comment",
      duration: 5,
      unlisted: true,
      slug: 'forum-account',
      summary: v.$pgettext("Task summary", "Create your forum account on forum.funkwhale.audio to start discussing with the Funkwhale community."),
      steps: [
        {
          title: v.$pgettext("Guide step title", 'Create your account on forum.funkwhale.audio'),
          content: [v.$pgettext("Guide step content", 'Our forum runs on Flarum, hosted at forum.funkwhale.audio. Click on the "Sign Up" button in the top bar and fill in your info.'),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Sign up on forum.funkwhale.audio'),
              url: 'https://forum.funkwhale.audio/',
            },
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/forum-account/signup-modal.png',
              caption: v.$pgettext("Task image caption", 'Sign up using your email adress, GitHub, or Funkwhale GitLab account')
            },
          ]
        },
        {
          title: v.$pgettext("Guide step title", 'Verify your e-mail inbox'),
          content: [v.$pgettext("Guide step content", "Shortly after signup, you should receive a confirmation e-mail containing a login link. Click it to log into your account. Request another one if you did not receive the e-mail within a few minutes."),],
        },
        {
          title: v.$pgettext("Guide step title", 'Customize your profile'),
          optional: true,
          content: [v.$pgettext("Guide step content", "Take a few minutes to customize your profile and upload your avatar. This will help other community members know who you are 😊"),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Profile form'),
              url: 'https://forum.funkwhale.audio/',
            }
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/forum-account/customize-profile.png',
              caption: v.$pgettext("Task image caption", 'Add a picture and some information about yourself')
            },
          ],
        },
        {
          title: v.$pgettext("Guide step title", 'Introduce yourself'),
          content: [v.$pgettext("Guide step content", 'Once you\'re all set up, you can post a quick introduction in the introduction topic. Click on the "Start a Discussion" button to create your first post.'),],
          links: [
            {
              text: v.$pgettext("Text for link in guide step", 'Introduce yourself'),
              url: 'https://forum.funkwhale.audio/t/introduction',
            },
          ],
          media: [
            {
              type: 'image',
              url: '/assets/guides/forum-account/introduce-yourself.png',
              caption: v.$pgettext("Task image caption", 'Write a short introduction to say hello')
            },
          ],
        }
      ]
    },
  ]
}
