import { createApp } from "vue";
import App from "./App.vue";
import router from './router'
import locales from '@/locales'
import { createGettext } from "@jshmrtn/vue3-gettext";
import Icon from "./components/Icon.vue";
import GuideMenu from "./components/guide/Menu.vue";
import GuideContent from "./components/guide/Content.vue";
import GuideStep from "./components/guide/Step.vue";
import StepImage from "./components/guide/Image.vue";
import Modal from "./components/Modal.vue";

let availableLanguages = (function() {
  let l = {};
  locales.locales.forEach(c => {
    l[c.code] = c.label;
  });
  return l;
})();
let defaultLanguage = "en_US";

const gettext = createGettext({
  availableLanguages: availableLanguages,
  defaultLanguage: defaultLanguage,
  translations: {},
  silent: true,
  setGlobalProperties: true
});

const mainApp = createApp(App)
  .use(router)
  .use(gettext);

mainApp.config.globalProperties.$translations = gettext.translations;
mainApp.component('icon', Icon);
mainApp.component('guide-menu', GuideMenu);
mainApp.component('guide-content', GuideContent);
mainApp.component('guide-step', GuideStep);
mainApp.component('step-image', StepImage);
mainApp.component('modal', Modal);

require("bulma/css/bulma.css");
require('fork-awesome/css/fork-awesome.min.css')

mainApp.mount("#app");
