const locales = require("./src/locales");
const path = require("path");
const PrerenderSPAPlugin = require("prerender-spa-plugin");

module.exports = {
  chainWebpack: (config) => {
    config.plugins.delete('prefetch');
  },
  configureWebpack: () => {
    if (process.env.NODE_ENV !== "production" || process.env.SKIP_PRERENDER) return;
    let baseRoutes = [
      "/",
      "/tasks",
      '/guides/become-backer',
      '/guides/talk-about-funkwhale',
      "/guides/share-feedback",
      "/guides/join-discussion",
      '/guides/forum-account',
      '/guides/translate',
      '/guides/gitlab-account',
      '/guides/report-a-bug',
      '/guides/request-a-feature',
    ];
    let finalRoutes = [];
    baseRoutes.forEach(p => {
      finalRoutes.push(p);
      locales.locales.forEach(l => {
        finalRoutes.push("/" + l.code + p);
      });
    });
    return {
      plugins: [
        new PrerenderSPAPlugin({
          routes: finalRoutes,
          staticDir: path.resolve(__dirname, "dist"),
          postProcess(renderedRoute) {
            return renderedRoute
          },
          renderer: new PrerenderSPAPlugin.PuppeteerRenderer({
            inject: {},
            maxConcurrentRoutes: 16,
            // for debugging
            // headless: false,
          })
        })
      ]
    };
  }
};
